#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import json
from unittest.mock import patch

import pytest
from messaging.messenger import AMQPServerInitializer, SenderIF
from messaging.router import Router


@pytest.fixture(scope="module")
def test_server_initializer() -> AMQPServerInitializer:
    with patch("messaging.messenger.Connection"):
        return AMQPServerInitializer("test")


class MockMessageSender(SenderIF):
    """Pretends to send a message"""

    destination = None

    def send_message(self, **message):
        """
        Don't send this message, but play it on TV

        :param message: message to send as Dict
        :return:
        """
        print(f"sending message: {message}")
        self.destination.receive_message(json.dumps(message))


@pytest.fixture(scope="module")
def test_router() -> Router:
    """
    Pytest fixture providing a Router class for testing

    :return: Test Router
    """
    messenger = MockMessageSender()
    router = Router("test", messenger)
    messenger.destination = router
    return router
