# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""fixing rootDirectory in calibration templates

Revision ID: aa5e540c480e
Revises: 731cab3f7cba
Create Date: 2021-05-12 16:33:53.675784

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "aa5e540c480e"
down_revision = "731cab3f7cba"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """

        UPDATE workflow_templates

        SET content = E'{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}'
        WHERE filename = 'metadata.json' AND workflow_name = 'std_calibration'
        """
    )

    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_cal</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_importdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_hanning</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_tbuff</Keyword>
                            <Value>1.5int</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*, *UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_vlasetjy</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_priorcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_testBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>semi</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_solint</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_fluxboot2</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_finalcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_applycals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_targetflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*CALIBRATE*,*TARGET*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_plotsummary</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intent</Keyword>
                            <Value>PHASE,BANDPASS</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>specmode</Keyword>
                            <Value>cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_masking</Keyword>
                            <Value>none</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_exportdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>'
        WHERE filename='PPR.xml' AND workflow_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content = E'{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "/tmp/workspaces_tmp/{{relative_path}}",
}'
        WHERE filename = 'metadata.json' AND workflow_name = 'std_calibration'
        """
    )

    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>/tmp/workspaces_tmp</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_cal</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_importdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_hanning</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_tbuff</Keyword>
                            <Value>1.5int</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*, *UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_vlasetjy</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_priorcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_testBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>semi</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_solint</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_fluxboot2</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_finalcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_applycals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_targetflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*CALIBRATE*,*TARGET*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_plotsummary</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intent</Keyword>
                            <Value>PHASE,BANDPASS</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>specmode</Keyword>
                            <Value>cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_masking</Keyword>
                            <Value>none</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_exportdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>'
        WHERE filename='PPR.xml' AND workflow_name='std_calibration'
        """
    )
